# !/usr/bin/python
# -*- coding: utf-8 -*-
# @Author:: Arthur Wu
# @Description:: 游客转会员登录，加购2个促销白名单商品，退购一个，并结算
# @Date:: 2024/11/21
import unittest,allure,time,pytest
from configs.globalObj import LOGGER
from YiMao.businessFunc.ClientApiLib import YMClientApi
from YiMao.businessFunc.ServiceApiLib import YMServiceApi
from YiMao.data.WuShangSceneTestData import *


DescName = "Vip013-游客转会员登录，加购2个促销白名单商品，退购一个，并结算"
@allure.story(f'[场景测试] {DescName}验证')
class Test_CVip013(unittest.TestCase):
    f'''@Date:: 2024/11/20
    @Author:: Arthur Wu
    @Desc::
    [购物车客户端] {DescName}
    1、武商测试环境，促销白名单商品 inputcode 分别为：
    '''
    def setUp(self) -> None:
        self.timestamp = int(time.time())
        self.ymc = YMClientApi(ShoppingCartMac)
        self.yms = YMServiceApi()
        self.vip_phone_num = VIPPhoneNumber
        self.promotional_whitelist_goods = PromotionalWhitelistGoods
        self.market_and_store_info = {
            "MarketId": MarketAndStoreDetails["putMarketId"],
            "StoreId": MarketAndStoreDetails["putStoreId"][0]
        }

    def test_CVip013_ReturnPromotionWhitelistProducts(self):
        allure.dynamic.description(f"描述：{DescName}")
        allure.step("[前置条件]：先调用管理平台接口，将指定商品添加到促销白名单中")
        pre_respomse = self.yms.add_promotional_product_whitelist(
            self.promotional_whitelist_goods, self.market_and_store_info
        )
        if pre_respomse['data'] is not None:
            LOGGER.info(f"---商品 {self.promotional_whitelist_goods['GoodsInputcode']} "
                        f"已添加到促销白名单中")
            allure.step("[业务步骤]：再调用客户端接口，执行加购操作")
            allure.step("步骤1：session开始")
            self.ymc.session_start()
            allure.step("步骤2：匿名登录")
            Payload01 = {"action": 0, "isAnon": True}
            LoginData = self.ymc.login_app_v2(Payload01)

            allure.step("步骤3：切换会员登录")
            Payload02 = {"action": 1, "code": self.vip_phone_num, "isAnon": False}
            self.ymc.login_app_v2(Payload02)

            '''step1：加购商品x，分别加购x件'''
            allure.step("步骤3：获取促销白名单商品信息")
            GoodsInfoData1 = self.ymc.get_goods_info(self.promotional_whitelist_goods["GoodsInputcode"])
            LOGGER.info(f"---获取的商品信息为：{GoodsInfoData1}")
            if GoodsInfoData1['data']['weight'] == 0:
                GoodsInfoData1['data']['weight'] = 300
            if GoodsInfoData1['msg'] != '加购商品不存在':
                allure.step("步骤4：加购白名单商品")
                AddGoodsResp = self.ymc.add_cart_goods(GoodsInfoData1, 1, LoginData)
                LOGGER.info(f"---加购商品返回结果：{AddGoodsResp}")

                ''' step2：随机退购一个商品，并结算 '''
                allure.step("\n步骤5：退购一件商品")
                GetGoodsInfoList = [GoodsInfoData1]
                self.ymc.delete_cart_goods(GetGoodsInfoList, LoginData, AddGoodsResp)

                allure.step("步骤6：获取购物车商品信息")
                self.ymc.get_cart_goods_info([GoodsInfoData1])
                allure.step("步骤7：请求订单结算")
                self.ymc.request_order_settlement(LoginData)
            else:
                LOGGER.info(f"---商品 {self.promotional_whitelist_goods["GoodsInputcode"]} 不存在")
                pytest.fail(f"---商品 {self.promotional_whitelist_goods["GoodsInputcode"]} 不存在")
        else:
            LOGGER.info(f"---添加商品 {self.promotional_whitelist_goods['GoodsInputcode']} "
                        f"到促销白名单失败")
            pytest.fail(f"---添加商品 {self.promotional_whitelist_goods['GoodsInputcode']} "
                            f"到促销白名单失败")

    def tearDown(self) -> None:
        allure.step("[后置处理]：删除添加的促销白名单商品")
        self.yms.delete_whitelist_goods()

if __name__ == '__main__':
    unittest.main(verbosity=2)